@@ -23,12 +23,12 @@ public:
   MinimalSubscriber()
   : Node("minimal_subscriber")
   {
-    subscription_ = this->create_subscription<std_msgs::msg::String>(
-      "topic",
-      10,
-      [this](std_msgs::msg::String::UniquePtr msg) {
+    auto topic_callback =
+      [this](std_msgs::msg::String::UniquePtr msg) -> void {
         RCLCPP_INFO(this->get_logger(), "I heard: '%s'", msg->data.c_str());
-      });
+      };
+    subscription_ =
+      this->create_subscription<std_msgs::msg::String>("topic", 10, topic_callback);
   }
 
 private:
